@@ -10,7 +10,7 @@ from torch import nn, einsum
 from einops import rearrange, repeat
 from einops.layers.torch import Rearrange
 
-from memorizing_transformers_pytorch.knn_memory import KNNMemory, KNNMemoryList, DEFAULT_KNN_MEMORY_MEMMAP_DIRECTORY
+from memorizing_transformers_pytorch.knn_memory import KNNMemoryList, DEFAULT_KNN_MEMORY_MEMMAP_DIRECTORY
 
 # helper functions
 
@@ -429,8 +429,7 @@ class MemorizingTransformer(nn.Module):
     ):
         knn_memories = self.create_knn_memories(**kwargs)
         yield knn_memories
-        for memory in knn_memories:
-            del memory
+        knn_memories.cleanup()
 
     def clear_memory(self, x, token_id):
         """ clears the KNN memories based on if the batch row contains the specified token id """
